"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MigrationService = void 0;
const symbol_sdk_1 = require("symbol-sdk");
const BootstrapUtils_1 = require("./BootstrapUtils");
const ConfigurationUtils_1 = require("./ConfigurationUtils");
class MigrationService {
    constructor(logger) {
        this.logger = logger;
    }
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    migrateAddresses(addresses) {
        const addressesFileName = 'addresses.yml';
        const networkType = addresses.networkType;
        if (!networkType) {
            throw new Error(`networkType must exist on current ${addressesFileName}`);
        }
        const migrations = this.getAddressesMigration(networkType);
        return BootstrapUtils_1.BootstrapUtils.migrate(this.logger, addressesFileName, addresses, migrations);
    }
    getAddressesMigration(networkType) {
        return [
            {
                description: 'Key names migration',
                migrate(from) {
                    (from.nodes || []).forEach((nodeAddresses) => {
                        var _a, _b;
                        if (nodeAddresses.signing) {
                            nodeAddresses.main = nodeAddresses.signing;
                        }
                        else {
                            if (nodeAddresses.ssl) {
                                nodeAddresses.main = ConfigurationUtils_1.ConfigurationUtils.toConfigAccount(symbol_sdk_1.Account.createFromPrivateKey(nodeAddresses.ssl.privateKey, networkType));
                            }
                        }
                        nodeAddresses.transport = ConfigurationUtils_1.ConfigurationUtils.toConfigAccountFomKeys(networkType, (_a = nodeAddresses === null || nodeAddresses === void 0 ? void 0 : nodeAddresses.node) === null || _a === void 0 ? void 0 : _a.publicKey, (_b = nodeAddresses === null || nodeAddresses === void 0 ? void 0 : nodeAddresses.node) === null || _b === void 0 ? void 0 : _b.privateKey);
                        if (!nodeAddresses.transport) {
                            nodeAddresses.transport = ConfigurationUtils_1.ConfigurationUtils.toConfigAccount(symbol_sdk_1.Account.generateNewAccount(networkType));
                        }
                        delete nodeAddresses.node;
                        delete nodeAddresses.signing;
                        delete nodeAddresses.ssl;
                    });
                    return from;
                },
            },
        ];
    }
}
exports.MigrationService = MigrationService;
